@@ -4,11 +4,10 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 
-use List::AllUtils qw( insert_after_string );
 use Markdent::Event::CodeBlock;
-use Markdent::Regexes qw( $BlockStart );
+use Markdent::Regexes qw( $BlockStart $HorizontalWS );
 
 use Moose::Role;
 
@@ -19,7 +18,7 @@ around _possible_block_matches => sub {
     my $self = shift;
 
     my @look_for = $self->$orig();
-    insert_after_string 'list', 'fenced_code_block', @look_for;
+    unshift @look_for, 'fenced_code_block';
 
     return @look_for;
 };
@@ -32,7 +31,7 @@ sub _match_fenced_code_block {
     return unless ${$text} =~ / \G
                                 $BlockStart
                                 ```
-                                \s?\{?\.?([\w-]+)?\}?\s*        # optional language name
+                                $HorizontalWS?\{?\.?([\w-]+)?\}?$HorizontalWS*   # optional language name
                                 \n
                                 (                # code block content
                                   (?:.|\n)+?
@@ -77,7 +76,7 @@ Markdent::Dialect::GitHub::BlockParser - Block parser for GitHub Markdown
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 DESCRIPTION
 
